<?php
/*Load the theme's custom Widgets so that they appear in the Elementor element panel.*/
add_action( 'elementor/widgets/register', 'biwors_register_elementor_widgets' );
function biwors_register_elementor_widgets() {
    if ( defined( 'ELEMENTOR_PATH' ) && class_exists('Elementor\Widget_Base') ) {
        /*Include Elementor Widget files here. */
        require_once( get_template_directory() . '/inc/backend/elementor/widgets/widgets.php' );
        require_once( get_template_directory() . '/inc/backend/elementor/widgets/header/widgets.php' );
    }
}

/*Add a custom 'category_biwors' category for to the Elementor element panel so that our theme's widgets have their own category.*/
add_action( 'elementor/init', function() {
    \Elementor\Plugin::$instance->elements_manager->add_category( 
        'category_biwors',
        [
            'title' => __( 'Biwors', 'biwors' ),
            'icon' => 'fa fa-plug', /*//default icon*/
        ],
        1 /*// position*/
    );
    \Elementor\Plugin::$instance->elements_manager->add_category( 
        'category_biwors_header',
        [
            'title' => __( 'OT Header', 'biwors' ),
            'icon' => 'fa fa-plug', /*//default icon*/
        ],
        2 /*// position*/
    );
});

/*Post types with Elementor*/
function biwors_add_cpt_support() {
    
    /*if exists, assign to $cpt_support var*/
    $cpt_support = get_option( 'elementor_cpt_support' );
    
    /*check if option DOESN'T exist in db*/
    if( ! $cpt_support ) {
        $cpt_support = [ 'page', 'ot_portfolio', 'ot_header_builders', 'ot_footer_builders' ]; //create array of our default supported post types
        update_option( 'elementor_cpt_support', $cpt_support ); //write it to the database
    }
    
    /*if it DOES exist, but portfolio is NOT defined*/
    else {
        $ot_portfolio       = in_array( 'ot_portfolio', $cpt_support );
        $ot_header_builders = in_array( 'ot_header_builders', $cpt_support );
        $ot_footer_builders = in_array( 'ot_footer_builders', $cpt_support );
        if( !$ot_portfolio ){
            $cpt_support[] = 'ot_portfolio'; //append to array
        }
        if( !$ot_header_builders ){
            $cpt_support[] = 'ot_header_builders'; //append to array
        }
        if( !$ot_footer_builders ){
            $cpt_support[] = 'ot_footer_builders'; //append to array
        }
        update_option( 'elementor_cpt_support', $cpt_support ); //update database
    }
    
    //otherwise do nothing, portfolio already exists in elementor_cpt_support option
}
add_action( 'elementor/init', 'biwors_add_cpt_support' );

/*Upload SVG for Elementor*/
function biwors_unfiltered_files_upload() {
    
    //if exists, assign to $cpt_support var
    $cpt_support = get_option( 'elementor_unfiltered_files_upload' );
    
    //check if option DOESN'T exist in db
    if( ! $cpt_support ) {
        $cpt_support = '1'; //create string value default to enable upload svg
        update_option( 'elementor_unfiltered_files_upload', $cpt_support ); //write it to the database
    }
}
add_action( 'elementor/init', 'biwors_unfiltered_files_upload' );

/*Header post type*/
add_action( 'init', 'biwors_create_header_builder' ); 
function biwors_create_header_builder() {
    register_post_type( 'ot_header_builders',
        array(
            'labels' => array(
                'name'              => esc_html__( 'Header Builder', 'biwors' ),
                'singular_name'     => esc_html__( 'Header Builder', 'biwors' ),
                'add_new'           => esc_html__( 'Add New', 'biwors' ),
                'add_new_item'      => esc_html__( 'Add New Header', 'biwors' ),
                'edit'              => esc_html__( 'Edit', 'biwors' ),
                'edit_item'         => esc_html__( 'Edit Header', 'biwors' ),
                'all_items'         => esc_html__( 'All Headers', 'biwors' ),
                'new_item'          => esc_html__( 'New Header', 'biwors' ),
                'view'              => esc_html__( 'View', 'biwors' ),
                'view_item'         => esc_html__( 'View Header', 'biwors' ),
                'search_items'      => esc_html__( 'Search Header', 'biwors' ),
                'not_found'         => esc_html__( 'No Header found', 'biwors' ),
                'not_found_in_trash'=> esc_html__( 'No Header found in Trash', 'biwors' ),
                'parent'            => esc_html__( 'Parent Header', 'biwors' )
            ),
            'hierarchical'          => false,
            'public'                => false,
            'show_ui'               => true,
            'menu_position'         => 60,
            'supports'              => array( 'title', 'editor' ),
            'menu_icon'             => 'dashicons-editor-kitchensink',
            'publicly_queryable'    => true,
            'exclude_from_search'   => true,
            'has_archive'           => false,
            'query_var'             => true,
            'can_export'            => true,
            'capability_type'       => 'post'
        )
    );
}

/*Footer post type*/
add_action( 'init', 'biwors_create_footer_builder' ); 
function biwors_create_footer_builder() {
    register_post_type( 'ot_footer_builders',
        array(
            'labels' => array(
                'name'              => esc_html__( 'Footer Builder', 'biwors' ),
                'singular_name'     => esc_html__( 'Footer Builder', 'biwors' ),
                'add_new'           => esc_html__( 'Add New', 'biwors' ),
                'add_new_item'      => esc_html__( 'Add New Footer', 'biwors' ),
                'edit'              => esc_html__( 'Edit', 'biwors' ),
                'edit_item'         => esc_html__( 'Edit Footer', 'biwors' ),
                'all_items'         => esc_html__( 'All Footers', 'biwors' ),
                'new_item'          => esc_html__( 'New Footer', 'biwors' ),
                'view'              => esc_html__( 'View', 'biwors' ),
                'view_item'         => esc_html__( 'View Footer', 'biwors' ),
                'search_items'      => esc_html__( 'Search Footer Builders', 'biwors' ),
                'not_found'         => esc_html__( 'No Footer found', 'biwors' ),
                'not_found_in_trash'=> esc_html__( 'No Footer found in Trash', 'biwors' ),
                'parent'            => esc_html__( 'Parent Footer', 'biwors' )
            ),
            'hierarchical'          => false,
            'public'                => false,
            'show_ui'               => true,
            'menu_position'         => 60,
            'supports'              => array( 'title', 'editor' ),
            'menu_icon'             => 'dashicons-editor-kitchensink',
            'publicly_queryable'    => true,
            'exclude_from_search'   => true,
            'has_archive'           => false,
            'query_var'             => true,
            'can_export'            => true,
            'capability_type'       => 'post'
        )
    );
}

/*Fix Elementor Pro*/
function biwors_register_elementor_locations( $elementor_theme_manager ) {

    $elementor_theme_manager->register_all_core_location();

}
add_action( 'elementor/theme/register_locations', 'biwors_register_elementor_locations' );

/* Add options to container */
add_action('elementor/element/container/section_layout_additional_options/after_section_end', function( $container, $args ) {

    /* header options */
    $container->start_controls_section(
        'section_custom_class',
        [
            'label' => __( 'For Header', 'biwors' ),
            'tab'   => \Elementor\Controls_Manager::TAB_LAYOUT,
        ]
    );
    $container->add_control(
        'sticky_class',
        [
            'label'        => __( 'Sticky On/Off', 'biwors' ),
            'type'         => Elementor\Controls_Manager::SWITCHER,
            'return_value' => 'sticky-header',
            'prefix_class' => '',
        ]
    );
    $container->add_control(
        'sticky_background',
        [
            'label'     => __( 'Background Scroll', 'biwors' ),
            'type'      => Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}}.is-stuck' => 'background: {{VALUE}};',
            ],
            'condition' => [
                'sticky_class' => 'sticky-header',
            ],
        ]
    );
    $container->add_responsive_control(
        'offset_space',
        [
            'label' => __( 'Offset', 'biwors' ),
            'type' => Elementor\Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 200,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}}.is-stuck' => 'top: {{SIZE}}{{UNIT}};',
                '.admin-bar {{WRAPPER}}.is-stuck' => 'top: calc({{SIZE}}{{UNIT}} + 32px);',
            ],
            'condition' => [
                'sticky_class' => 'sticky-header',
            ],
        ]
    );

    $container->end_controls_section();

}, 10, 2 );

/*Add options to container*/
add_action('elementor/element/container/section_shape_divider/after_section_end', function( $container, $args ) {

    /*Particles*/
    $container->start_controls_section(
        'container_custom_class',
        [
            'label' => __( 'Particles', 'biwors' ),
            'tab' => \Elementor\Controls_Manager::TAB_STYLE,
        ]
    );
    $container->add_control(
        'container_particles_class',
        [
            'label'        => __( 'Particles On/Off', 'biwors' ),
            'type'         => Elementor\Controls_Manager::SWITCHER,
            'return_value' => 'particles-js',
            'prefix_class' => '',
        ]
    );
    $container->add_control(
        'container_add_particles_color',
        [
            'label'        => __( 'Particles Colors', 'biwors' ),
            'type'         => Elementor\Controls_Manager::TEXT,
            'default'      => '#f7e5ff,#c5ddff,#ffffff',
            'condition' => [
                'container_particles_class' => 'particles-js',
            ]
        ]
    );
    $container->end_controls_section();

}, 10, 2 );
add_action( 'elementor/frontend/container/before_render',function( $element ) {
    // Make sure we are in a section element
    if( 'container' !== $element->get_name() ) {
        return;
    }
    $container = $element->get_settings_for_display();
    if( $container['container_add_particles_color'] ){
        $element->add_render_attribute( '_wrapper', 'data-color', $container['container_add_particles_color'] );
    }
    
}, 10, 3);
