<?php
namespace Elementor; // Custom widgets must be defined in the Elementor namespace
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly (security measure)

/**
 * Widget Name: Hover Image
 */
class Biwors_Hover_Image extends Widget_Base{

 	// The get_name() method is a simple one, you just need to return a widget name that will be used in the code.
	public function get_name() {
		return 'ot-hover-image';
	}

	// The get_title() method, which again, is a very simple one, you need to return the widget title that will be displayed as the widget label.
	public function get_title() {
		return __( 'OT Hover Image', 'biwors' );
	}

	// The get_icon() method, is an optional but recommended method, it lets you set the widget icon. you can use any of the eicon or font-awesome icons, simply return the class name as a string.
	public function get_icon() {
		return 'eicon-image';
	}

	// The get_categories method, lets you set the category of the widget, return the category name as a string.
	public function get_categories() {
		return [ 'category_biwors' ];
	}

	protected function register_controls() {

		/*Content Image*/
		$this->start_controls_section(
			'section_side_a_content',
			[
				'label' => __( 'Image', 'biwors' ),
			]
		);

		$this->add_control(
			'image_front',
			[
				'label' => __( 'Choose Image', 'biwors' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'link_to',
			[
				'label' => esc_html__( 'Link', 'biwors' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'none',
				'options' => [
					'none' => esc_html__( 'None', 'biwors' ),
					'file' => esc_html__( 'Media File', 'biwors' ),
					'custom' => esc_html__( 'Custom URL', 'biwors' ),
				],
				'condition' => [
					'image_front[url]!' => '',
				],
			]
		);
		$this->add_control(
			'link',
			[
				'label' => esc_html__( 'Link', 'biwors' ),
				'type' => Controls_Manager::URL,
				'condition' => [
					'image_front[url]!' => '',
					'link_to' => 'custom',
				],
				'show_label' => false,
			]
		);
		$this->end_controls_section();

		/*Icon*/
		$this->start_controls_section(
			'section_back_icon',
			[
				'label' => __( 'Hover', 'biwors' ),
			]
		);

		$this->add_control(
			'hover_image_back_icon',
			[
				'label'            => __( 'Icon', 'biwors' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default'          => [
					'value'   => 'fas fa-star',
					'library' => 'fa-solid',
				],
			]
		);

		$this->end_controls_section();

		//Style
		$this->start_controls_section(
			'style_section',
			[
				'label' => __( 'Image', 'biwors' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
			'align',
			[
				'label' => __( 'Alignment', 'biwors' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left'    => [
						'title' => __( 'Left', 'biwors' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'biwors' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'biwors' ),
						'icon' => 'eicon-text-align-right',
					]
				],
				'selectors' => [
					'{{WRAPPER}}' => 'text-align: {{VALUE}};',
				]
			]
		);

		$this->add_control(
			'background_overlay',
			[
				'label' => __( 'Background Overlay', 'biwors' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} span.bg' => 'background-color: {{VALUE}};',
				]
			]
		);
		$this->add_responsive_control(
			'image_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'biwors' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .ot-hover-image' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		//Icon
		$this->add_control(
			'heading_icon',
			[
				'label' => __( 'Icon', 'biwors' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'icon_size',
			[
				'label' => __( 'Size', 'biwors' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 6,
						'max' => 200,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .ot-hover-image i' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .ot-hover-image svg' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Color', 'biwors' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ot-hover-image i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .ot-hover-image svg' => 'fill: {{VALUE}};'
				],
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_render_attribute( 'image_wrap', 'class', ['ot-hover-image', 'overlay'] );
		$link = $this->get_link_url( $settings );

		if ( $link ) {
			if ( 'custom' !== $settings['link_to'] ) {
				$this->add_render_attribute( 'link', 'data-src', $link );
				$this->add_render_attribute( 'link', 'data-title', Control_Media::get_image_title( $settings['image_front'] ) );
				$this->add_render_attribute( 'image_wrap', 'class', 'image-popup-gallery' );
			}else{
				$this->add_link_attributes( 'link', $link );
			}
		} 

		$this->add_render_attribute( 'link', 'class', 'ot-hover-image__link' );

		?>

		<div <?php echo $this->print_render_attribute_string( 'image_wrap' ) ?>>
			<?php if ( $link ) { ?>
			<a <?php echo $this->print_render_attribute_string( 'link' ) ?>></a>
			<?php } ?>
			<figure class="ot-hover-image__inner">
				<?php echo Group_Control_Image_Size::get_attachment_image_html( $settings, 'image_front' ); ?>
				<span class="bg flex-middle">
					<?php 
				    	Icons_Manager::render_icon( $settings['hover_image_back_icon'], [ 'aria-hidden' => 'true' ] );
			    	?>
				</span>
			</figure>
	    </div>

	    <?php
	}

	protected function get_link_url( $settings ) {
		if ( 'none' === $settings['link_to'] ) {
			return false;
		}

		if ( 'custom' === $settings['link_to'] ) {
			if ( empty( $settings['link']['url'] ) ) {
				return false;
			}

			return $settings['link'];
		}

		return [
			'url' => $settings['image_front']['url'],
		];
	}

}
// After the Biwors_Hover_Image class is defined, I must register the new widget class with Elementor:
Plugin::instance()->widgets_manager->register( new Biwors_Hover_Image() );