<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Biwors
 */

/** Add body class by filter **/
add_filter( 'body_class', 'biwors_body_class_names', 999 );
function biwors_body_class_names( $classes ) {
	
	$theme = wp_get_theme();
	if( is_child_theme() ) { $theme = wp_get_theme()->parent(); }

  	$classes[] = 'biwors-theme-ver-'.$theme->version;

  	$classes[] = 'wordpress-version-'.get_bloginfo( 'version' );

  	return $classes;
}

/**
 *  Add specific CSS class to header
 */
function biwors_header_class() {

	$header_classes = '';

	if ( biwors_get_option('header_fixed') != false ){
		$header_classes = 'header-transparent';
	}else{
		$header_classes = 'header-static';
	}
	if ( function_exists('rwmb_meta') ) {
		if( rwmb_meta('is_trans') == 'yes'){
			$header_classes = 'header-transparent';
		}elseif( rwmb_meta('is_trans') == 'no'){
			$header_classes = 'header-static';
		}
	}
    echo html_entity_decode( esc_attr( $header_classes ) );
}

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function biwors_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'biwors_pingback_header' );

/*Get layout post & page.*/
if ( ! function_exists( 'biwors_get_layout' ) ) :
	function biwors_get_layout() {
		/*Get layout.*/
		if ( is_page() && !is_home() && function_exists( 'rwmb_meta' ) ) {
			$page_layout = rwmb_meta('page_layout');
		} elseif ( is_single() ) {
			$page_layout = biwors_get_option( 'single_post_layout' );
		} else {
			$page_layout = biwors_get_option( 'blog_layout' );
		}

		return $page_layout;
	}
endif;

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
if ( ! function_exists( 'biwors_content_columns' ) ) :
	function biwors_content_columns() {

		$blog_content_width = array();

		/*Check if layout is one column.*/
		if ( 'content-sidebar' === biwors_get_layout() && is_active_sidebar( 'primary' ) ) {
			$blog_content_width[] = 'col-lg-9 col-md-9 col-sm-12 col-xs-12';
		}elseif ('sidebar-content' === biwors_get_layout() && is_active_sidebar( 'primary' ) ) {
			$blog_content_width[] = 'col-lg-9 col-md-9 col-sm-12 col-xs-12 pull-right';
		}else{
			$blog_content_width[] = 'col-lg-12 col-md-12 col-sm-12 col-xs-12';
		}

		/*return the $classes array*/
    	echo implode( ' ', $blog_content_width );
	}
endif;

/* Select blog style */
if ( ! function_exists( 'biwors_blog_style' ) ) :
	function biwors_blog_style() {

		$blog_style = array();
		// Check if layout is one column.
		if ( biwors_get_option( 'blog_style' ) === 'grid' ) {
			$blog_style[] = 'blog-grid';
			$blog_style[] = biwors_get_option( 'blog_columns' );
		} else {
			$blog_style[] = 'blog-list';
		}
		// return the $classes array
    	echo implode( ' ', $blog_style );
	}
endif;

/**
 * Portfolio Columns
 */
if ( ! function_exists( 'biwors_portfolio_option_class' ) ) :
	function biwors_portfolio_option_class() {

		$portfolio_option_class = array();

		if( biwors_get_option('portfolio_column') == "2cl" ){
			$portfolio_option_class[] = 'pf_2_cols';
		}elseif( biwors_get_option('portfolio_column') == "4cl" ) {
			$portfolio_option_class[] = 'pf_4_cols';
		}else{
			$portfolio_option_class[] = 'pf_3_cols';
		}

		if( biwors_get_option('portfolio_style') == "gallery-mode" ){
			$portfolio_option_class[] = 'image-popup-gallery';
		}
	    /*return the $classes array*/
	    echo implode( ' ', $portfolio_option_class );
	}
endif;

/**
 * Change Posts Per Page for Portfolio Archive.
 * 
 * @param object $query data
 *
 */
function biwors_change_portfolio_posts_per_page( $query ) {
	$portfolio_ppp = (!empty( biwors_get_option('portfolio_posts_per_page') ) ? biwors_get_option('portfolio_posts_per_page') : '6');

	if ( !is_singular() && !is_admin() ) {		
	    if ( $query->is_post_type_archive( 'ot_portfolio' ) || $query->is_tax('portfolio_cat') && ! is_admin() && $query->is_main_query() ) {
	        $query->set( 'posts_per_page', $portfolio_ppp );
	    }
	}
    return $query;
}
add_filter( 'pre_get_posts', 'biwors_change_portfolio_posts_per_page' );

/**
 * Load More Ajax Portfolio
 */
add_action( 'wp_enqueue_scripts', 'biwors_script_and_styles', 1 );
function biwors_script_and_styles() {
	global $wp_query;

	// register our main script but do not enqueue it yet
	wp_register_script( 'biwors_scripts', get_template_directory_uri() . '/js/myloadmore.js', array('jquery'), time() );

	// now the most interesting part
	// we have to pass parameters to myloadmore.js script but we can get the parameters values only in PHP
	// you can define variables directly in your HTML but I decided that the most proper way is wp_localize_script()
	wp_localize_script( 'biwors_scripts', 'biwors_loadmore_params', array(
		'ajaxurl' => admin_url( 'admin-ajax.php' ), // WordPress AJAX
	) );

 	wp_enqueue_script( 'biwors_scripts' );
}

add_action('wp_ajax_loadmore', 'biwors_loadmore_ajax_handler'); // wp_ajax_{action}
add_action('wp_ajax_nopriv_loadmore', 'biwors_loadmore_ajax_handler'); // wp_ajax_nopriv_{action}

function biwors_loadmore_ajax_handler(){
	$offset_items  = ( isset($_POST['offset_items']) ) ? $_POST['offset_items'] : 0;
	$cats     	   = ( isset($_POST['data_cates']) ) ? $_POST['data_cates'] : 0;
	$data_load     = ( isset($_POST['settings']['p_more']) ) ? $_POST['settings']['p_more'] : 3;
	$is_latest	   = '';

	if( $_POST['data_cates'] != '' ){
		$args = array(
			'post_type' 	 => 'ot_portfolio',
			'post_status' 	 => 'publish',
			'posts_per_page' => $data_load,
			'offset'         => $offset_items,
			'tax_query' => array(
				array(
					'taxonomy' => 'portfolio_cat',
					'field' => 'term_id',
					'terms' => explode(",",$cats),
				),
			), 
		);
	}else{
		$args = array(
			'post_type' 	 => 'ot_portfolio',
			'post_status' => 'publish',
			'posts_per_page' => $data_load,
			'offset'         => $offset_items,
		);
	}
	$args_temp = array(
		'settings' => $_POST['settings']
	);

	$wp_query = new \WP_Query($args);
		while ($wp_query -> have_posts()) : $wp_query -> the_post();
			if( ($offset_items + $data_load) >= ($wp_query->found_posts) ) {
				$is_latest = 'latest';
			};
			$args_temp['is_latest'] = $is_latest;
			
			get_template_part( 'template-parts/content', 'project-filter', $args_temp);
			
		endwhile; wp_reset_postdata();

	die;
}

/**
 * Back-To-Top on Footer
 */
if( !function_exists('biwors_custom_back_to_top') ) {
    function biwors_custom_back_to_top() {     
	    if( biwors_get_option('backtotop') != false ){
	    	echo '<a id="back-to-top" href="#" class="show"><i class="ot-flaticon-right-arrow"></i></a>';
	    }
    }
}
add_action('wp_footer', 'biwors_custom_back_to_top');

/**
 * Google Analytics
 */
if ( ! function_exists( 'biwors_hook_javascript' ) ) {
	function biwors_hook_javascript() {
		if ( biwors_get_option('js_code') != '' ) {
	    ?>
	    	<!-- Google Analytics code -->
	    	<script type="text/javascript">
	            <?php echo biwors_get_option('js_code'); ?>
	        </script>
	    <?php
	    }
	}
}
add_action('wp_head', 'biwors_hook_javascript');

/**
 * Shortcode render current year
 * [oceanthemes_date time_custom="F j, Y"]
 */
function oceanthemes_date_func( $atts ) {
    $date_format = shortcode_atts( array(
        'time_custom' => 'Y',        
    ), $atts );

    $dt = new DateTime("now");
    $gmt_timestamp = $dt->format("{$date_format['time_custom']}");

    return $gmt_timestamp;
}
add_shortcode( 'oceanthemes_date', 'oceanthemes_date_func' );